@@ -2,6 +2,17 @@ from typing import Dict
 
 
 def elastic_to_search_results(res: Dict, score_modifier: float, doc_class):
+    """Converts Elasticsearch result to Kiri SearchResults object
+
+    Args:
+        res: dictionary/JSON returned from Elasticsearch
+        score_modifier: value to be subtracted from each result's score
+        doc_class: Type of Document object to be included in SearchResult object
+
+    Returns:
+        SearchResults equivalent of Elastic result
+    """
+
     from ..search import SearchResult, SearchResults
 
     hits = res.get("hits")
